@@ -132,6 +132,15 @@ void DelegateRecycler::syncModel()
     }
     QQmlContext *ctx = QQmlEngine::contextForObject(m_item)->parentContext();
     ctx->setContextProperty(QStringLiteral("model"), newModel);
+
+    //try to bind all properties
+    QObject *modelObj = newModel.value<QObject *>();
+    if (modelObj) {
+        const QMetaObject *metaObj = modelObj->metaObject();
+        for (int i = metaObj->propertyOffset(); i < metaObj->propertyCount(); ++i) {
+            ctx->setContextProperty(QString::fromUtf8(metaObj->property(i).name()), metaObj->property(i).read(modelObj));
+        }
+    }
 }
 
 void DelegateRecycler::syncModelData()
@@ -160,10 +169,16 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
     }
 
     if (!m_propertiesTracker) {
-        QQmlComponent *propertiesTrackerComponent = new QQmlComponent(qmlEngine(this), this);
+        static QMap<QQmlEngine*, QQmlComponent*> propertiesTrackerComponent;
+        auto engine = qmlEngine(this);
+        auto it = propertiesTrackerComponent.find(engine);
+        if (it == propertiesTrackerComponent.end()) {
+            connect(engine, &QObject::destroyed, engine, [engine] { propertiesTrackerComponent.remove(engine); });
+            it = propertiesTrackerComponent.insert(engine, new QQmlComponent(engine, engine));
 
-        propertiesTrackerComponent->setData(QByteArrayLiteral("import QtQuick 2.3\nQtObject{property int trackedIndex: index; property var trackedModel: typeof model != 'undefined' ? model : null; property var trackedModelData: typeof modelData != 'undefined' ? modelData : null}"), QUrl());
-        m_propertiesTracker = propertiesTrackerComponent->create(QQmlEngine::contextForObject(this));
+            (*it)->setData(QByteArrayLiteral("import QtQuick 2.3\nQtObject{property int trackedIndex: index; property var trackedModel: typeof model != 'undefined' ? model : null; property var trackedModelData: typeof modelData != 'undefined' ? modelData : null}"), QUrl());
+        }
+        m_propertiesTracker = (*it)->create(QQmlEngine::contextForObject(this));
 
         connect(m_propertiesTracker, SIGNAL(trackedIndexChanged()), this, SLOT(syncIndex()));
         connect(m_propertiesTracker, SIGNAL(trackedModelChanged()), this, SLOT(syncModel()));
@@ -203,9 +218,18 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
             //share context object in order to never lose track of global i18n()
             ctx->setContextObject(eng->rootContext()->contextObject());
         }
+
+        QObject *modelObj = m_propertiesTracker->property("trackedModel").value<QObject *>();
+        if (modelObj) {
+            const QMetaObject *metaObj = modelObj->metaObject();
+            for (int i = metaObj->propertyOffset(); i < metaObj->propertyCount(); ++i) {
+                ctx->setContextProperty(QString::fromUtf8(metaObj->property(i).name()), metaObj->property(i).read(modelObj));
+            }
+        }
         ctx->setContextProperty(QStringLiteral("model"), m_propertiesTracker->property("trackedModel"));
         ctx->setContextProperty(QStringLiteral("modelData"), m_propertiesTracker->property("trackedModelData"));
         ctx->setContextProperty(QStringLiteral("index"), m_propertiesTracker->property("trackedIndex"));
+        ctx->setContextProperty(QStringLiteral("delegateRecycler"), this);
 
         QObject * obj = component->create(ctx);
         m_item = qobject_cast<QQuickItem *>(obj);
@@ -213,19 +237,37 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
             obj->deleteLater();
         } else {
             connect(m_item.data(), &QObject::destroyed, ctx, &QObject::deleteLater);
+            //if the user binded an explicit width, consider it, otherwise base upon implicit
+            m_widthFromItem = m_item->width() > 0 && m_item->width() != m_item->implicitWidth();
+            m_heightFromItem = m_item->height() > 0 && m_item->height() != m_item->implicitHeight();
+
+            if (m_widthFromItem && m_heightFromItem) {
+                connect(m_item.data(), &QQuickItem::heightChanged, this, [this]() {
+                    updateSize(false);
+                });
+            }
         }
     } else {
-        QQmlContext *ctx = QQmlEngine::contextForObject(m_item)->parentContext();
+        syncModel();
 
-        ctx->setContextProperty(QStringLiteral("model"), m_propertiesTracker->property("trackedModel"));
+        QQmlContext *ctx = QQmlEngine::contextForObject(m_item)->parentContext();
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
         ctx->setContextProperty(QStringLiteral("modelData"), m_propertiesTracker->property("trackedModelData"));
         ctx->setContextProperty(QStringLiteral("index"), m_propertiesTracker->property("trackedIndex"));
+        ctx->setContextProperty(QStringLiteral("delegateRecycler"), QVariant::fromValue<QObject*>(this));
+#else
+        ctx->setContextProperties({ QQmlContext::PropertyPair{ QStringLiteral("modelData"), m_propertiesTracker->property("trackedModelData") },
+                                    QQmlContext::PropertyPair{ QStringLiteral("index"), m_propertiesTracker->property("trackedIndex")},
+                                    QQmlContext::PropertyPair{ QStringLiteral("delegateRecycler"), QVariant::fromValue<QObject*>(this) }
+                                 });
+#endif
     }
 
     if (m_item) {
         m_item->setParentItem(this);
         connect(m_item.data(), &QQuickItem::implicitWidthChanged, this, &DelegateRecycler::updateHints);
         connect(m_item.data(), &QQuickItem::implicitHeightChanged, this, &DelegateRecycler::updateHints);
+
         updateSize(true);
     }
 
@@ -257,8 +299,8 @@ void DelegateRecycler::updateSize(bool parentResized)
         return;
     }
 
-    const bool needToUpdateWidth = parentResized && widthValid();
-    const bool needToUpdateHeight = parentResized && heightValid();
+    const bool needToUpdateWidth = !m_widthFromItem && parentResized && widthValid();
+    const bool needToUpdateHeight = !m_heightFromItem && parentResized && heightValid();
 
     if (parentResized) {
         m_item->setPosition(QPoint(0,0));
@@ -277,11 +319,16 @@ void DelegateRecycler::updateSize(bool parentResized)
 
     m_updatingSize = true;
 
+    if (m_heightFromItem) {
+        setHeight(m_item->height());
+    }
+    if (m_widthFromItem) {
+        setWidth(m_item->width());
+    }
+
     setImplicitSize(m_item->implicitWidth() >= 0 ? m_item->implicitWidth() : m_item->width(),
-                    m_item->implicitHeight() >= 0 ? m_item->implicitHeight() : m_item->height());
+                m_item->implicitHeight() >= 0 ? m_item->implicitHeight() : m_item->height());
+
 
     m_updatingSize = false;
 }
-
-
-#include <moc_delegaterecycler.cpp>
