@@ -128,14 +128,6 @@ void PlatformThemePrivate::syncCustomPalette()
         setPaletteColor(customPalette, state, QPalette::HighlightedText, q->highlightedTextColor());
         setPaletteColor(customPalette, state, QPalette::ToolTipBase, q->backgroundColor());
         setPaletteColor(customPalette, state, QPalette::ToolTipText, q->textColor());
-/*Those shouldn't be needed
-        customPalette.setColor(state, QPalette::Light, KColorScheme::shade(backgroundColor(), KColorScheme::LightShade));
-        customPalette.setColor(state, QPalette::Midlight, KColorScheme::shade(backgroundColor(), KColorScheme::MidlightShade));
-        customPalette.setColor(state, QPalette::Mid, KColorScheme::shade(backgroundColor(), KColorScheme::MidShade));
-        customPalette.setColor(state, QPalette::Dark, KColorScheme::shade(backgroundColor(), KColorScheme::DarkShade));
-        customPalette.setColor(state, QPalette::Shadow, KColorScheme::shade(backgroundColor(), KColorScheme::ShadowShade));
-
-        setPaletteColor(customPalette, state, QPalette::AlternateBase, backgroundColor().darker(120));*/
         setPaletteColor(customPalette, state, QPalette::Link, q->linkColor());
         setPaletteColor(customPalette, state, QPalette::LinkVisited, q->visitedLinkColor());
     }
@@ -228,7 +220,7 @@ void PlatformTheme::setColorSet(PlatformTheme::ColorSet colorSet)
 
     d->m_colorSet = colorSet;
 
-    for (PlatformTheme *t : d->m_childThemes) {
+    for (PlatformTheme *t : qAsConst(d->m_childThemes)) {
         if (t->inherit()) {
             t->setColorSet(colorSet);
            /* if (colorSet == Custom) {
@@ -268,7 +260,7 @@ void PlatformTheme::setColorGroup(PlatformTheme::ColorGroup colorGroup)
 
     d->m_colorGroup = colorGroup;
 
-    for (PlatformTheme *t : d->m_childThemes) {
+    for (PlatformTheme *t : qAsConst(d->m_childThemes)) {
         if (t->inherit()) {
             t->setColorGroup(colorGroup);
         }
@@ -516,7 +508,7 @@ void PlatformTheme::setDefaultFont(const QFont &font)
 
 
 #define PROPAGATECUSTOMCOLOR(colorName, color)\
-            for (PlatformTheme *t : d->m_childThemes) {\
+            for (PlatformTheme *t : qAsConst(d->m_childThemes)) {\
                 if (t->inherit()) {\
                     t->set##colorName(color);\
                 }\
@@ -688,7 +680,7 @@ void PlatformTheme::setPalette(const QPalette &palette)
 QIcon PlatformTheme::iconFromTheme(const QString &name, const QColor &customColor)
 {
     QIcon icon = QIcon::fromTheme(name);
-    if (!icon.isNull() && (name.endsWith("-symbolic") || customColor != Qt::transparent)) {
+    if (!icon.isNull() && (name.endsWith(QLatin1String("-symbolic")) || customColor != Qt::transparent)) {
         icon.setIsMask(true);
     }
     return icon;
@@ -706,11 +698,13 @@ PlatformTheme *PlatformTheme::qmlAttachedProperties(QObject *object)
     } else if (!s_factoryChecked) {
         s_factoryChecked = true;
 #if QT_CONFIG(library)
-        for (const QString &path : QCoreApplication::libraryPaths()) {
-            QDir dir(path + "/kf5/kirigami");
-            for (const QString &fileName : dir.entryList(QDir::Files)) {
+        const auto libraryPaths = QCoreApplication::libraryPaths();
+        for (const QString &path : libraryPaths) {
+            QDir dir(path + QStringLiteral("/kf5/kirigami"));
+            const auto fileNames = dir.entryList(QDir::Files);
+            for (const QString &fileName : fileNames) {
                 //TODO: env variable?
-                if (fileName.startsWith(QQuickStyle::name())) {
+                if (!QQuickStyle::name().isEmpty() && fileName.startsWith(QQuickStyle::name())) {
                     QPluginLoader loader(dir.absoluteFilePath(fileName));
                     QObject *plugin = loader.instance();
                     //TODO: load actually a factory as plugin
